@@ -14,12 +14,12 @@ use {Poll, Token};
 /// There are two types of `Evented` values.
 ///
 /// * **System** handles, which are backed by sockets or other system handles.
-///     These `Evented` handles will be monitored by the system selector. In this
-///     case, an implementation of `Evented` delegates to a lower level handle.
+///   These `Evented` handles will be monitored by the system selector. In this
+///   case, an implementation of `Evented` delegates to a lower level handle.
 ///
 /// * **User** handles, which are driven entirely in user space using
-///     [`Registration`] and [`SetReadiness`]. In this case, the implementer takes
-///     responsibility for driving the readiness state changes.
+///   [`Registration`] and [`SetReadiness`]. In this case, the implementer takes
+///   responsibility for driving the readiness state changes.
 ///
 /// [`Poll`]: ../struct.Poll.html
 /// [`Registration`]: ../struct.Registration.html
@@ -570,7 +570,7 @@ impl fmt::Debug for PollOpt {
                 if one {
                     write!(fmt, " | ")?
                 }
-                write!(fmt, "{}", msg)?;
+                write!(fmt, "{msg}")?;
 
                 one = true
             }
@@ -1037,7 +1037,7 @@ impl fmt::Debug for Ready {
                 if one {
                     write!(fmt, " | ")?
                 }
-                write!(fmt, "{}", msg)?;
+                write!(fmt, "{msg}")?;
 
                 one = true
             }
