@@ -242,11 +242,9 @@ pub mod test {
         assert_eq!(context_dimension.lines, 88);
 
         let rich_text_id = 0;
-        let route_id = 0;
         let context = create_mock_context(
             VoidListener {},
             WindowId::from(0),
-            route_id,
             rich_text_id,
             context_dimension,
         );
@@ -295,11 +293,9 @@ pub mod test {
         assert_eq!(context_dimension.lines, 88);
 
         let rich_text_id = 0;
-        let route_id = 0;
         let context = create_mock_context(
             VoidListener {},
             WindowId::from(0),
-            route_id,
             rich_text_id,
             context_dimension,
         );
